==> groupoffice-com-4.0.144.tar.gz: groupoffice-com-4.0.144/modules/email/language/nl.php <==
<?php


$l['name'] = 'Email';
$l['description'] = 'Uitgebreide Web-based email client. Het is voor iedere gebruiker mogelijk om emails te verzenden en te ontvangen.';
$l['feedbackNoReciepent'] = 'U heeft geen ontvanger ingevuld';
$l['feedbackSMTPProblem'] = 'Er was een probleem in de communicatie met SMTP: ';
$l['feedbackUnexpectedError'] = 'Er was een onverwacht probleem bij het opstellen van de email: ';
$l['feedbackCreateFolderFailed'] = 'Map kan niet worden gemaakt';
$l['feedbackSubscribeFolderFailed'] = 'Fout bij het opslaan van de gegevens';
$l['feedbackUnsubscribeFolderFailed'] = 'Fout bij het opslaan van de gegevens';
$l['feedbackCannotConnect'] = 'Kan geen verbinding maken met %1$s op poort %3$s<br /><br />De mail server antwoorde: %2$s';
$l['spam']='Spam';
$l['trash']='Prullenbak';
$l['sent']='Verzonden items';
$l['drafts']='Concepten';
$l['no_subject']='Geen onderwerp';
$l['no_recipients']='Vertrouwelijke ontvangers';
$l['original_message']='--- Origineel bericht volgt ---';
$l['notification_subject']='Gelezen: %s';
$l['notification_body']='Uw bericht met onderwerp "%s" is getoond op %s';
$l['errorGettingMessage']='Kon bericht niet ophalen van server';
$l['no_recipients_drafts']='Geen ontvangers';
$l['usage_limit'] = '%s van %s gebruikt';
$l['feedbackDeleteFolderFailed']= 'Failed to delete folder';
$l['event']='Afspraak';
$l['calendar']='agenda';
$l['quotaError']="Uw mailbox is vol. Leeg eerst uw 'Prullenbak' map. Indien die map al leeg is en uw mailbox is nog steeds vol, dan dient u de 'Prullenbak' map uit te schakelen om berichten uit andere mappen te kunnen verwijderen. U kunt de map uitschakkelen bij:\n\nInstellingen -> Accounts -> Dubbelklik account -> Mappen.";
$l['draftsDisabled']="Het bericht kon niet worden opgeslagen omdat de 'Concepten' map is uitgeschakeld.<br /><br />Ga naar Beheer -> Accounts -> Dubbelklik account -> Mappen om deze in te stellen.";
$l['noSaveWithPop3']='Het bericht kon niet worden opgeslagen omdat POP3 accounts dit niet ondersteunen.';
$l['goAlreadyStarted']='{product_name} was already started. The e-mail composer is now loaded in {product_name}. Close this window and compose your message in {product_name}.';
$l['replyHeader']='Op %s, %s om %s schreef %s:';
$l['noUidNext']='Uw mailserver ondersteund geen UIDNEXT. De \'Concepten\' map is nu automatisch uitgeschakeld voor deze account.';
$l['disable_trash_folder']='Kon het bericht niet naar de prullenbak verplaatsen.Mogelijk door gebrek aan schijfruimte. U kunt uw mailbox opschonen door de prullenbak uit te schakelen bij Beheer -> Accounts -> Dubbelklik account -> Mappen.';
$l['error_move_folder']='Kon de map niet verplaatsen';
$l['error_getaddrinfo']='Ongeldig host adres opgegeven';
$l['error_authentication']='Ongeldige gebruikersnaam of wachtwoord';
$l['error_connection_refused']='De verbinding werd geweigerd. Controleer het host adres en port a.u.b.';
$l['iCalendar_event_invitation']='Dit bericht bevat een uitnodiging voor een afspraak.';
$l['iCalendar_event_not_found']='Dit bericht bevat een update voor een niet bestaande afspraak.';
$l['iCalendar_update_available']='Dit bericht bevat een update voor een bestaande afspraak.';
$l['iCalendar_update_old']='Dit bericht bevat een afspraak die al is verwerkt.';
$l['iCalendar_event_cancelled']='Dit bericht bevat een annulering voor een afspraak.';
$l['iCalendar_event_invitation_declined']='Dit bericht bevat een door u geweigerde uitnodiging voor een afspraak.';
$l['untilDateError']='Ik probeerde de volgende "Tot-Datum" te verwerken, maar de verwerking ervan is gestopt omdat er een fout optrad';$l["messages"]='Berichten';
$l["message"]='Bericht';
$l["inbox"]='Postvak in';
$l["accounts"]='Accounts';
$l["account"]='E-mail Account';
$l["crossAccountMove"]='Sorry, u kunt geen berichten naar een andere account verplaatsen';
$l["compose"]='Opstellen';
$l["reply"]='Beantwoorden';
$l["replyAll"]='Allen beantwoorden';
$l["markAsRead"]='Markeren als gelezen';
$l["markAsUnread"]='Markeren als ongelezen';
$l["flag"]='Markeren met vlag';
$l["unflag"]='Vlag demarkeren';
$l["flagged"]='Gemarkeerd';
$l["unflagged"]='Gedemarkeerd';
$l["root"]='Root';
$l["folders"]='Mappen';
$l["filter"]='Filter';
$l["filters"]='Filters';
$l["selectFolderDelete"]='Selecteer a.u.b. een map om te verwijderen';
$l["selectFolderAdd"]='Selecteer eerst een map waaraan je de nieuwe map wilt toevoegen. Klik daarna op \'Toevoegen\'';
$l["selectFolderRename"]='Selecteer a.u.b. een map om te hernoemen';
$l["forward"]='Doorsturen';
$l["resetSearch"]='Zoeken beëindigen';
$l["emailMessage"]='E-mail bericht';
$l["host"]='Host';
$l["field"]='Veld';
$l["contains"]='Bevat';
$l["moveToFolder"]='Verplaats naar map';
$l["incomingMail"]='Binnenkomende mail';
$l["advanced"]='Geavanceerd';
$l["ssl"]='SSL';
$l["tls"]='TLS';
$l["novalidateCert"]='Certificaat niet valideren';
$l["port"]='Poort';
$l["rootMailbox"]='Root mailbox';
$l["manageFolders"]='Beheer mappen';
$l["sendItemsFolder"]='Verzonden berichten';
$l["trashFolder"]='Prullenbak';
$l["draftsFolder"]='Concepten';
$l["sender"]='Van veld';
$l["subject"]='Onderwerp';
$l["toField"]='Naar veld';
$l["ccField"]='CC veld';
$l["bccField"]='BCC veld';
$l["keyword"]='Sleutelwoord';
$l["notification"]='Vraag om een leesbevestiging';
$l["high"]='Hoog';
$l["normal"]='Normaal';
$l["low"]='Laag';
$l["from"]='Van';
$l["sendTo"]='Verzenden naar';
$l["cc"]='CC';
$l["bcc"]='BCC';
$l["selectTemplate"]='Selecteer sjabloon';
$l["composeEmail"]='Stel een e-mail bericht op';
$l["send"]='Verzenden';
$l["extraOptions"]='Extra opties';
$l["attachments"]='Bijlagen';
$l["show"]='Tonen';
$l["noAccount"]='U heeft uw e-mail account nog niet ingesteld. Ga naar Start menu -> E-mail -> Beheer -> Accounts om uw eerste e-mail account op te zetten.';
$l["attachFiles"]='Voeg bestanden van uw computer toe';
$l["uploadAttachments"]='Upload bijlagen';
$l["startTransfer"]='Start overdracht';
$l["cantEditFolder"]='U kunt deze map niet aanpassen';
$l["cantDeleteInboxFolder"]='U kunt de INBOX map niet verwijderen';
$l["cantRenameInboxFolder"]='U kunt de INBOX map niet hernoemen';
$l["enterFolderName"]='Voer een mapnaam in:';
$l["addFolder"]='Map toevoegen';
$l["to"]='Aan';
$l["downloadAllAsZip"]='Download alles als zipbestand';
$l["body"]='Body';
$l["recievedBefore"]='Ontvangen voor';
$l["recievedSince"]='Ontvangen sinds';
$l["answered"]='Beantwoord';
$l["unanswered"]='Onbeantwoord';
$l["viewed"]='Bekeken';
$l["outgoingMail"]='Uitgaande mail';
$l["encryption"]='Encryptie';
$l["type"]='Type';
$l["noEncryption"]='Geen encryptie';
$l["noAccountTitle"]='Geen account';
$l["attachFilesPC"]='Toevoegen vanaf PC';
$l["attachFilesGO"]='Toevoegen vanaf {product_name}';
$l["priority"]='Prioriteit';
$l["read"]='Gelezen';
$l["NA"]='N.v.t.';
$l["emptyFolder"]='Map leegmaken';
$l["emptyFolderConfirm"]='Weet u zeker dat u \'{name}\' wilt LEGEN?';
$l["addUnknownRecipients"]='Voeg onbekende ontvanger toe';
$l["addUnknownRecipientsText"]='U heeft een e-mail verzonden naar een of meer ontvangers die niet in uw adresboek staan. Klik op een naam als u deze wilt toevoegen of sluit dit venster.';
$l["addUnknownSenders"]='Voeg onbekende verzenders toe';
$l["addUnknownSendersText"]='U wilt geselecteerde emailverzenders toevoegen aan een adreslijst. Daarvoor moeten eerst de volgende verzenders toegevoegd worden aan een Group-Office adresboek. Klik op een naam als u deze wilt toevoegen of sluit dit venster.';
$l["vacation"]='Automatisch beantwoorden';
$l["vacationActive"]='Activeer automatisch beantwoorden';
$l["vacationSubject"]='Onderwerp';
$l["vacationBody"]='Inhoud';
$l["renameFolder"]='Map hernoemen';
$l["addToRecipients"]= 'Voeg toe aan ontvangers';
$l["addToCC"]= 'Voeg toe aan CC';
$l["addToBCC"]= 'Voeg toe aan BCC';
$l["viewSource"]='Bron weergeven';
$l["sendNotification"]='De afzender van dit bericht wil graag een bevestiging dat dit bericht is aangekomen op: %s. Wilt u deze bevestiging nu versturen?';
$l["searchOnSender"]='Toon berichten in huidige map';
$l["blocked"]= '{blocked_images} externe afbeeldingen werden voor uw veiligheid geblokkeerd.';
$l["unblock"]= 'Klik hier om de blokkade op te heffen';
$l["loadEmailFirst"]= 'Om deze functie te gebruiken moet u eerst uw e-mail laden door op het tabblad E-mail te klikken.';
$l["confirmEmptySubject"]='U heeft geen onderwerp ingevuld. Weet u zeker dat u dit bericht zonder onderwerp wilt verzenden?';
$l["usage"]='Schijfgebruik';
$l["searchGO"]='{product_name} doorzoeken';
$l["toggleWindowPosition"]= 'Verander berichtvenster positie';
$l["closeUploadDialog"]='Sluit eerst het upload venster of wacht tot de upload klaar is.';
$l["signature"]='Handtekening';
$l["defaultProgram"]='Standaard e-mail programma';
$l["htmlMarkup"]= 'Gebruik HTML opmaak';
$l["confirmLostChanges"]= 'Uw wijzigingen gaan verloren. Weet u het zeker?';
$l["manageAliases"]='Beheer afzendaliassen';
$l["addSendersTo"]='Voeg afzenders toe aan...';
$l["deleteSendersFrom"]='Verwijder afzenders van...';
$l["defaultTemplate"]='Stel geselecteerd sjabloon in als standaard';
$l["moving"]='Bezig met verplaatsen...';
$l["alias"]="Alias";
$l["aliases"]="Aliasen";
$l["accountId"]="Account";
$l["email"]="E-mail";
$l["orderFilters"]='U kunt door slepen de volgorde van filters veranderen.';
$l["orderAccounts"]='U kunt door slepen de volgorde van accounts veranderen.';
$l["groups"]='Groepen';
$l["showUnread"]='Toon ongelezen';
$l["searchFrom"]='Afzender';
$l["searchTo"]='Ontvanger';
$l["searchCC"]='Ontvanger (CC)';
$l["replaceEmailText"]='Deze contactpersoon heeft al drie email addressen in het profiel. U kunt 1 van de bestaande vervangen door te klikken op het email adres dat u wilt vervangen.';
$l["skipUnknownRecipientsAction"]='Dit scherm in het vervolg niet tonen';
$l["skipUnknownRecipients"]='Toon onbekende ontvanger dialoog niet';
$l["alwaysRequestNotification"]='Altijd om een leesbevestiging vragen';
$l["icalendarUpdateEvent"]='Afspraak bijwerken';
$l["icalendarDeleteEvent"]='Afspraak verwijderen';
$l["icalendarAcceptInvitation"]='Accepteren';
$l["icalendarDeclineInvitation"]='Weigeren';
$l["icalendarTentativeInvitation"]='Voorlopig';
$l["alwaysRespondToNotifications"]='Altijd antwoorden op een leesbevestiging';
$l["youHaveNewMails"]= 'U heeft {new} nieuwe e-mail bericht(en)';
$l["icalendarEventUpdated"]='Afspraak is bijgewerkt.';
$l["icalendarEventCreated"]='Afspraak is aangemaakt.';
$l["icalendarEventDeleted"]='Afspraak is verwijderd.';
$l["icalendarInvitationDeclined"]='Uitnodiging is geweigerd.';
$l["icalendarDeleteEventConfirm"]='Weet u zeker dat u deze afspraak wilt verwijderen?';
$l["sending"]='Verzenden...';
$l["defaultFontSize"]= 'Standaard lettergrootte';
$l["emailFiles"]='E-mail bestanden';
$l["shareFolder"]= 'Delen';
$l["readPerm"]='Lezen';
$l["writePerm"]='Schrijven';
$l["deletePerm"]='Verwijderen';
$l["createMailboxPerm"]='Mailbox aanmaken';
$l["deleteMailboxPerm"]='Mailbox verwijderen';
$l["adminPerm"]='Beheren';
$l["anyField"]='Alle velden';
$l["deleteOldMails"]= 'Oude mails verwijderen';
$l["deleteOldMailsInstructions"]= 'Selecteer een datum. Als u vervolgens op OK klikt, zullen alle emails in de geselecteerde folder tot dat datum permanent worden verwijderd.';
$l["folder"]= 'Folder';
$l["deleteOldMailsSure1"]= 'Deze handeling kan niet ongedaan gemaakt worden. Weet u zeker dat u alle mails van deze folder tot';
$l["deleteOldMailsSure2"]= ' wilt verwijderen?';
$l["nDeletedMailsTxt"]= 'Het aantal verwijderde emails is';
$l["deletingEmails"]= 'Emails aan het verwijderen...';
$l["everythingBefore"]= 'Alle emails voor';
$l["alsoChildren"]= 'Deze bewerking ook toepassen op emails in subfolders.';
$l['failedRecipients']='Kon het bericht niet verzenden naar';
$l['subscribeFolders']='Abonneren op mappen';

$l['imapLoginFailed']='Authententicatie mislukt voor gebruiker "%username".';
$l['tryNewCredentials']='Probeert u het a.u.b. met een andere IMAP wachtwoord.';

$l['moveTo']='Verplaatsen naar';

$l['useAccount']='Account gebruiken';

$l['mailbox']='Mailbox';
$l['checkUnseen']='Controleer deze map automatisch op nieuwe berichten';

$l['sieveNote']='Niet alle functies worden ondersteund. Raadpleeg de handleiding.';

$l['attachedAppointmentInfo']="Informatie over bijgevoegde afspraak";

$l["forwardTo"]='Mail doorsturen aan';
$l["markFolderReadConfirm"]='Weet u zeker dat u alle berichten in map \'{name}\' als gelezen wilt markeren?';
$l["moveOldMails"]= 'Verplaats oude berichten';
$l["moveOldMailsInstructions"]= 'Selecteer een datum. Wanneer u vervolgens op OK klikt, worden alle berichten voor die datum naar de doelmap verplaatst.';
$l["moveOldMailsSure"]= 'Weet u zeker dat u alle berichten ouder dan {date} van "{source}" naar "{target}" wilt verplaatsen?';
$l["nMovedMailsTxt"]= 'Het aantal verplaatste berichten: ';
$l['autolinked']='Dit bericht is automatisch gekoppeld aan %s';
$l['defaultProgramInstructions']='<p>Om {product_name} als uw standaard e-mail programma in te stellen voor Windows kunt u dit <a class="normal-link" href="{url}">registerbestand</a> uitvoeren.</p>';
$l['xssDetected']="This message may contain malicious content. Click here to view the filtered message anyway.";
$l['xssMessageHidden']='Message hidden for security reasons';
$l['ignoreSentFolder']='Store replies in the same folder as the original message';
$l['sourceAndTargetSame']="Source and target mailbox may not be the same";
$l['noEmailFolders']= 'No folders have been added.';
$l['winmailNoFiles']="This winmail attachment does not contain any files.";
$l['cantDeleteSpecialFolder']="You can't delete the trash, sent items or drafts folder";

==> groupoffice-com-4.1.7.tar.gz: groupoffice-com-4.1.7/modules/email/language/nl.php <==
<?php


$l['name'] = 'Email';
$l['description'] = 'Uitgebreide Web-based email client. Het is voor iedere gebruiker mogelijk om emails te verzenden en te ontvangen.';
$l['feedbackNoReciepent'] = 'U heeft geen ontvanger ingevuld';
$l['feedbackSMTPProblem'] = 'Er was een probleem in de communicatie met SMTP: ';
$l['feedbackUnexpectedError'] = 'Er was een onverwacht probleem bij het opstellen van de email: ';
$l['feedbackCreateFolderFailed'] = 'Map kan niet worden gemaakt';
$l['feedbackSubscribeFolderFailed'] = 'Fout bij het opslaan van de gegevens';
$l['feedbackUnsubscribeFolderFailed'] = 'Fout bij het opslaan van de gegevens';
$l['feedbackCannotConnect'] = 'Kan geen verbinding maken met %1$s op poort %3$s<br /><br />De mail server antwoorde: %2$s';
$l['spam']='Spam';
$l['trash']='Prullenbak';
$l['sent']='Verzonden items';
$l['drafts']='Concepten';
$l['no_subject']='Geen onderwerp';
$l['no_recipients']='Vertrouwelijke ontvangers';
$l['original_message']='--- Origineel bericht volgt ---';
$l['notification_subject']='Gelezen: %s';
$l['notification_body']='Uw bericht met onderwerp "%s" is getoond op %s';
$l['errorGettingMessage']='Kon bericht niet ophalen van server';
$l['no_recipients_drafts']='Geen ontvangers';
$l['usage_limit'] = '%s van %s gebruikt';
$l['feedbackDeleteFolderFailed']= 'Failed to delete folder';
$l['event']='Afspraak';
$l['calendar']='agenda';
$l['quotaError']="Uw mailbox is vol. Leeg eerst uw 'Prullenbak' map. Indien die map al leeg is en uw mailbox is nog steeds vol, dan dient u de 'Prullenbak' map uit te schakelen om berichten uit andere mappen te kunnen verwijderen. U kunt de map uitschakkelen bij:\n\nInstellingen -> Accounts -> Dubbelklik account -> Mappen.";
$l['draftsDisabled']="Het bericht kon niet worden opgeslagen omdat de 'Concepten' map is uitgeschakeld.<br /><br />Ga naar Beheer -> Accounts -> Dubbelklik account -> Mappen om deze in te stellen.";
$l['noSaveWithPop3']='Het bericht kon niet worden opgeslagen omdat POP3 accounts dit niet ondersteunen.';
$l['goAlreadyStarted']='{product_name} was already started. The e-mail composer is now loaded in {product_name}. Close this window and compose your message in {product_name}.';
$l['replyHeader']='Op %s, %s om %s schreef %s:';
$l['noUidNext']='Uw mailserver ondersteund geen UIDNEXT. De \'Concepten\' map is nu automatisch uitgeschakeld voor deze account.';
$l['disable_trash_folder']='Kon het bericht niet naar de prullenbak verplaatsen.Mogelijk door gebrek aan schijfruimte. U kunt uw mailbox opschonen door de prullenbak uit te schakelen bij Beheer -> Accounts -> Dubbelklik account -> Mappen.';
$l['error_move_folder']='Kon de map niet verplaatsen';
$l['error_getaddrinfo']='Ongeldig host adres opgegeven';
$l['error_authentication']='Ongeldige gebruikersnaam of wachtwoord';
$l['error_connection_refused']='De verbinding werd geweigerd. Controleer het host adres en port a.u.b.';
$l['iCalendar_event_invitation']='Dit bericht bevat een uitnodiging voor een afspraak.';
$l['iCalendar_event_not_found']='Dit bericht bevat een update voor een niet bestaande afspraak.';
$l['iCalendar_update_available']='Dit bericht bevat een update voor een bestaande afspraak.';
$l['iCalendar_update_old']='Dit bericht bevat een afspraak die al is verwerkt.';
$l['iCalendar_event_cancelled']='Dit bericht bevat een annulering voor een afspraak.';
$l['iCalendar_event_invitation_declined']='Dit bericht bevat een door u geweigerde uitnodiging voor een afspraak.';
$l['untilDateError']='Ik probeerde de volgende "Tot-Datum" te verwerken, maar de verwerking ervan is gestopt omdat er een fout optrad';
$l["messages"]='Berichten';
$l["message"]='Bericht';
$l["inbox"]='Postvak in';
$l["accounts"]='Accounts';
$l["account"]='E-mail Account';
$l["crossAccountMove"]='Sorry, u kunt geen berichten naar een andere account verplaatsen';
$l["compose"]='Opstellen';
$l["reply"]='Beantwoorden';
$l["replyAll"]='Allen beantwoorden';
$l["markAsRead"]='Markeren als gelezen';
$l["markAsUnread"]='Markeren als ongelezen';
$l["flag"]='Markeren met vlag';
$l["unflag"]='Vlag demarkeren';
$l["flagged"]='Gemarkeerd';
$l["unflagged"]='Gedemarkeerd';
$l["root"]='Root';
$l["folders"]='Mappen';
$l["filter"]='Filter';
$l["filters"]='Filters';
$l["selectFolderDelete"]='Selecteer a.u.b. een map om te verwijderen';
$l["selectFolderAdd"]='Selecteer eerst een map waaraan je de nieuwe map wilt toevoegen. Klik daarna op \'Toevoegen\'';
$l["selectFolderRename"]='Selecteer a.u.b. een map om te hernoemen';
$l["forward"]='Doorsturen';
$l["resetSearch"]='Zoeken beëindigen';
$l["emailMessage"]='E-mail bericht';
$l["host"]='Host';
$l["field"]='Veld';
$l["contains"]='Bevat';
$l["moveToFolder"]='Verplaats naar map';
$l["incomingMail"]='Binnenkomende mail';
$l["advanced"]='Geavanceerd';
$l["ssl"]='SSL';
$l["tls"]='TLS';
$l["novalidateCert"]='Certificaat niet valideren';
$l["port"]='Poort';
$l["rootMailbox"]='Root mailbox';
$l["manageFolders"]='Beheer mappen';
$l["sendItemsFolder"]='Verzonden berichten';
$l["trashFolder"]='Prullenbak';
$l["draftsFolder"]='Concepten';
$l["sender"]='Van veld';
$l["subject"]='Onderwerp';
$l["toField"]='Naar veld';
$l["ccField"]='CC veld';
$l["bccField"]='BCC veld';
$l["keyword"]='Sleutelwoord';
$l["notification"]='Vraag om een leesbevestiging';
$l["high"]='Hoog';
$l["normal"]='Normaal';
$l["low"]='Laag';
$l["from"]='Van';
$l["sendTo"]='Verzenden naar';
$l["cc"]='CC';
$l["bcc"]='BCC';
$l["selectTemplate"]='Selecteer sjabloon';
$l["composeEmail"]='Stel een e-mail bericht op';
$l["send"]='Verzenden';
$l["extraOptions"]='Extra opties';
$l["attachments"]='Bijlagen';
$l["show"]='Tonen';
$l["noAccount"]='U heeft uw e-mail account nog niet ingesteld. Ga naar Start menu -> E-mail -> Beheer -> Accounts om uw eerste e-mail account op te zetten.';
$l["attachFiles"]='Voeg bestanden van uw computer toe';
$l["uploadAttachments"]='Upload bijlagen';
$l["startTransfer"]='Start overdracht';
$l["cantEditFolder"]='U kunt deze map niet aanpassen';
$l["cantDeleteInboxFolder"]='U kunt de INBOX map niet verwijderen';
$l["cantRenameInboxFolder"]='U kunt de INBOX map niet hernoemen';
$l["enterFolderName"]='Voer een mapnaam in:';
$l["addFolder"]='Map toevoegen';
$l["to"]='Aan';
$l["downloadAllAsZip"]='Download alles als zipbestand';
$l["body"]='Body';
$l["recievedBefore"]='Ontvangen voor';
$l["recievedSince"]='Ontvangen sinds';
$l["answered"]='Beantwoord';
$l["unanswered"]='Onbeantwoord';
$l["viewed"]='Bekeken';
$l["outgoingMail"]='Uitgaande mail';
$l["encryption"]='Encryptie';
$l["type"]='Type';
$l["noEncryption"]='Geen encryptie';
$l["noAccountTitle"]='Geen account';
$l["attachFilesPC"]='Toevoegen vanaf PC';
$l["attachFilesGO"]='Toevoegen vanaf {product_name}';
$l["priority"]='Prioriteit';
$l["read"]='Gelezen';
$l["NA"]='N.v.t.';
$l["emptyFolder"]='Map leegmaken';
$l["emptyFolderConfirm"]='Weet u zeker dat u \'{name}\' wilt LEGEN?';
$l["addUnknownRecipients"]='Voeg onbekende ontvanger toe';
$l["addUnknownRecipientsText"]='U heeft een e-mail verzonden naar een of meer ontvangers die niet in uw adresboek staan. Klik op een naam als u deze wilt toevoegen of sluit dit venster.';
$l["addUnknownSenders"]='Voeg onbekende verzenders toe';
$l["addUnknownSendersText"]='U wilt geselecteerde emailverzenders toevoegen aan een adreslijst. Daarvoor moeten eerst de volgende verzenders toegevoegd worden aan een Group-Office adresboek. Klik op een naam als u deze wilt toevoegen of sluit dit venster.';
$l["vacation"]='Automatisch beantwoorden';
$l["vacationActive"]='Activeer automatisch beantwoorden';
$l["vacationSubject"]='Onderwerp';
$l["vacationBody"]='Inhoud';
$l["renameFolder"]='Map hernoemen';
$l["addToRecipients"]= 'Voeg toe aan ontvangers';
$l["addToCC"]= 'Voeg toe aan CC';
$l["addToBCC"]= 'Voeg toe aan BCC';
$l["viewSource"]='Bron weergeven';
$l["sendNotification"]='De afzender van dit bericht wil graag een bevestiging dat dit bericht is aangekomen op: %s. Wilt u deze bevestiging nu versturen?';
$l["searchOnSender"]='Toon berichten in huidige map';
$l["blocked"]= '{blocked_images} externe afbeeldingen werden voor uw veiligheid geblokkeerd.';
$l["unblock"]= 'Klik hier om de blokkade op te heffen';
$l["loadEmailFirst"]= 'Om deze functie te gebruiken moet u eerst uw e-mail laden door op het tabblad E-mail te klikken.';
$l["confirmEmptySubject"]='U heeft geen onderwerp ingevuld. Weet u zeker dat u dit bericht zonder onderwerp wilt verzenden?';
$l["usage"]='Schijfgebruik';
$l["searchGO"]='{product_name} doorzoeken';
$l["toggleWindowPosition"]= 'Verander berichtvenster positie';
$l["closeUploadDialog"]='Sluit eerst het upload venster of wacht tot de upload klaar is.';
$l["signature"]='Handtekening';
$l["defaultProgram"]='Standaard e-mail programma';
$l["htmlMarkup"]= 'Gebruik HTML opmaak';
$l["confirmLostChanges"]= 'Uw wijzigingen gaan verloren. Weet u het zeker?';
$l["manageAliases"]='Beheer afzendaliassen';
$l["addSendersTo"]='Voeg afzenders toe aan...';
$l["deleteSendersFrom"]='Verwijder afzenders van...';
$l["defaultTemplate"]='Stel geselecteerd sjabloon in als standaard';
$l["moving"]='Bezig met verplaatsen...';
$l["alias"]="Alias";
$l["aliases"]="Aliasen";
$l["accountId"]="Account";
$l["email"]="E-mail";
$l["orderFilters"]='U kunt door slepen de volgorde van filters veranderen.';
$l["orderAccounts"]='U kunt door slepen de volgorde van accounts veranderen.';
$l["groups"]='Groepen';
$l["showUnread"]='Toon ongelezen';
$l["searchFrom"]='Afzender';
$l["searchTo"]='Ontvanger';
$l["searchCC"]='Ontvanger (CC)';
$l["replaceEmailText"]='Deze contactpersoon heeft al drie email addressen in het profiel. U kunt 1 van de bestaande vervangen door te klikken op het email adres dat u wilt vervangen.';
$l["skipUnknownRecipientsAction"]='Dit scherm in het vervolg niet tonen';
$l["skipUnknownRecipients"]='Toon onbekende ontvanger dialoog niet';
$l["alwaysRequestNotification"]='Altijd om een leesbevestiging vragen';
$l["icalendarUpdateEvent"]='Afspraak bijwerken';
$l["icalendarDeleteEvent"]='Afspraak verwijderen';
$l["icalendarAcceptInvitation"]='Accepteren';
$l["icalendarDeclineInvitation"]='Weigeren';
$l["icalendarTentativeInvitation"]='Voorlopig';
$l["alwaysRespondToNotifications"]='Altijd antwoorden op een leesbevestiging';
$l["youHaveNewMails"]= 'U heeft {new} nieuwe e-mail bericht(en)';
$l["icalendarEventUpdated"]='Afspraak is bijgewerkt.';
$l["icalendarEventCreated"]='Afspraak is aangemaakt.';
$l["icalendarEventDeleted"]='Afspraak is verwijderd.';
$l["icalendarInvitationDeclined"]='Uitnodiging is geweigerd.';
$l["icalendarDeleteEventConfirm"]='Weet u zeker dat u deze afspraak wilt verwijderen?';
$l["sending"]='Verzenden...';
$l["defaultFontSize"]= 'Standaard lettergrootte';
$l["emailFiles"]='E-mail bestanden';
$l["shareFolder"]= 'Delen';
$l["readPerm"]='Lezen';
$l["writePerm"]='Schrijven';
$l["deletePerm"]='Verwijderen';
$l["createMailboxPerm"]='Mailbox aanmaken';
$l["deleteMailboxPerm"]='Mailbox verwijderen';
$l["adminPerm"]='Beheren';
$l["anyField"]='Alle velden';
$l["deleteOldMails"]= 'Oude mails verwijderen';
$l["deleteOldMailsInstructions"]= 'Selecteer een datum. Als u vervolgens op OK klikt, zullen alle emails in de geselecteerde folder tot dat datum permanent worden verwijderd.';
$l["folder"]= 'Folder';
$l["deleteOldMailsSure1"]= 'Deze handeling kan niet ongedaan gemaakt worden. Weet u zeker dat u alle mails van deze folder tot';
$l["deleteOldMailsSure2"]= ' wilt verwijderen?';
$l["nDeletedMailsTxt"]= 'Het aantal verwijderde emails is';
$l["deletingEmails"]= 'Emails aan het verwijderen...';
$l["everythingBefore"]= 'Alle emails voor';
$l["alsoChildren"]= 'Deze bewerking ook toepassen op emails in subfolders.';
$l['failedRecipients']='Kon het bericht niet verzenden naar';
$l['subscribeFolders']='Abonneren op mappen';

$l['imapLoginFailed']='Authententicatie mislukt voor gebruiker "%username".';
$l['tryNewCredentials']='Probeert u het a.u.b. met een andere IMAP wachtwoord.';

$l['moveTo']='Verplaatsen naar';

$l['useAccount']='Account gebruiken';

$l['mailbox']='Mailbox';
$l['checkUnseen']='Controleer deze map automatisch op nieuwe berichten';

$l['sieveNote']='Niet alle functies worden ondersteund. Raadpleeg de handleiding.';

$l["forwardTo"]='Mail doorsturen aan';
$l["markFolderReadConfirm"]='Weet u zeker dat u alle berichten in map \'{name}\' als gelezen wilt markeren?';
$l["moveOldMails"]= 'Verplaats oude berichten';
$l["moveOldMailsInstructions"]= 'Selecteer een datum. Wanneer u vervolgens op OK klikt, worden alle berichten voor die datum naar de doelmap verplaatst.';
$l["moveOldMailsSure"]= 'Weet u zeker dat u alle berichten ouder dan {date} van "{source}" naar "{target}" wilt verplaatsen?';
$l["nMovedMailsTxt"]= 'Het aantal verplaatste berichten: ';
$l['autolinked']='Dit bericht is automatisch gekoppeld aan %s';
$l['defaultProgramInstructions']='<p>Om {product_name} als uw standaard e-mail programma in te stellen voor Windows kunt u dit <a class="normal-link" href="{url}">registerbestand</a> uitvoeren.</p>';
$l['xssDetected']="This message may contain malicious content. Click here to view the filtered message anyway.";
$l['xssMessageHidden']='Message hidden for security reasons';
$l['ignoreSentFolder']='Store replies in the same folder as the original message';
$l['sourceAndTargetSame']="Source and target mailbox may not be the same";
$l['noEmailFolders']= 'No folders have been added.';
$l['winmailNoFiles']="This winmail attachment does not contain any files.";
$l['cantDeleteSpecialFolder']="You can't delete the trash, sent items or drafts folder";
$l['useAccount']='Account gebruiken';

$l['storePassword']='Wachtwoord permanent opslaan';

$l['attachedAppointmentInfo']="Informatie over bijgevoegde afspraak";

$l["copyingMessages"]='Bezig met kopiëren van berichten...';
